pub fn transcode<'de, D, S>(de: &mut D, ser: &mut S) -> Result<(), Error>Expand description
Transcodes a value from a deserializer into a serializer.
This reads the next value of the deserializer and serializes it. To
transcode many values, Transcoder reuses the buffer.